:mod:`anyconfig.backend.python.builtin`
==============================================

.. automodule:: anyconfig.backend.python.builtin
    :members:
    :special-members:
    :private-members:
    :undoc-members:
    :show-inheritance:
